aboutsummaryrefslogtreecommitdiff
path: root/hotline/user.go
diff options
context:
space:
mode:
authorJeff Halter <868228+jhalter@users.noreply.github.com>2024-01-24 10:41:51 -0800
committerJeff Halter <868228+jhalter@users.noreply.github.com>2024-01-24 10:41:51 -0800
commit76d0c1f61d5981603389e6267bf62636f34bef1f (patch)
tree41534fcb6f03671670b0727d40302c14b6f9def0 /hotline/user.go
parent6aa45e93e2b9d1bd91c9fa6a736f0c669d3ae303 (diff)
Rename encode/decode methods
Diffstat (limited to 'hotline/user.go')
-rw-r--r--hotline/user.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/hotline/user.go b/hotline/user.go
index 34fe1ab..5b1b705 100644
--- a/hotline/user.go
+++ b/hotline/user.go
@@ -56,19 +56,19 @@ func ReadUser(b []byte) (*User, error) {
return u, nil
}
// DecodeUserString decodes an obfuscated user string from a client
// e.g. 98 8a 9a 8c 8b => "guest"
-func DecodeUserString(obfuText []byte) (clearText string) {
+func decodeString(obfuText []byte) (clearText string) {
for _, char := range obfuText {
clearText += string(rune(255 - uint(char)))
}
return clearText
}
// negateString takes []byte s containing cleartext and rotates by 255 into obfuscated cleartext.
// The Hotline protocol uses this format for sending passwords over network.
// Not secure, but hey, it was the 90s!
-func negateString(clearText []byte) []byte {
+func encodeString(clearText []byte) []byte {
obfuText := make([]byte, len(clearText))
for i := 0; i < len(clearText); i++ {
obfuText[i] = 255 - clearText[i]
@@ -56,19 +56,19 @@ func ReadUser(b []byte) (*User, error) {
return u, nil
}
-// DecodeUserString decodes an obfuscated user string from a client
+// decodeString decodes an obfuscated user string from a client
// e.g. 98 8a 9a 8c 8b => "guest"
@@ -56,19 +56,19 @@ func ReadUser(b []byte) (*User, error) {
return clearText
}
-// negateString takes []byte s containing cleartext and rotates by 255 into obfuscated cleartext.
+// encodeString takes []byte s containing cleartext and rotates by 255 into obfuscated cleartext.
// The Hotline protocol uses this format for sending passwords over network.
// Not secure, but hey, it was the 90s!